@@ -6,14 +6,13 @@ use anyhow::{Context, Ok, Result};
 use argon2::Argon2;
 use argon2::Params;
 use rand::{prelude::StdRng, Rng, RngCore, SeedableRng};
-use sha3::Digest;
-use sha3::Sha3_512;
 use std::time::Instant;
 use std::{
     fs::{metadata, File},
     io::{BufReader, Read, Write},
     process::exit,
 };
+use tiny_keccak::{Hasher, KangarooTwelve};
 
 pub fn encrypt_file(
     input: &str,
@@ -121,11 +120,18 @@ pub fn encrypt_file(
     );
 
     if sha_sum {
-        let mut hasher = Sha3_512::new();
-        serde_json::to_writer(&mut hasher, &data).context("Can't write to the sha3-512 hasher")?;
-        let hash = hasher.finalize();
+        let start_time = Instant::now();
+        let mut hash = [0u8; 32];
+        let mut hasher = KangarooTwelve::new(&[]);
+        hasher.update(&serde_json::to_vec(&data).context("Unable to serialize data as a vector")?);
+        hasher.finalize(&mut hash);
         let hash_b64 = base64::encode(hash);
-        println!("Hash of the encrypted file is: {}", hash_b64);
+        let duration = start_time.elapsed();
+        println!(
+            "Hash of the encrypted file is: {} [took {:.2}s]",
+            hash_b64,
+            duration.as_secs_f32()
+        );
     }
 
     Ok(())
